@@ -392,7 +392,7 @@ PLEX BOOL smtp_send_blob(const char * url, const char * fromaddr, const char * f
 	    goto ssb_end;
 	val_from_str(v, subj);
 	val_dict_add(root, v);
-	if ((envelope = blob_xlat(envelope, (const char *)blob_data(template), blob_left(template), root)) == NULL)
+	if ((envelope = blob_xlat(envelope, (const char *)blob_data(template), blob_left(template), NULL, NULL, root)) == NULL)
 	    goto ssb_end;
     } else return result;
     if ((ctx = pcurl_alloc_ctx(url, PCURL_USE_STREAM_LOCAL_WRITE|PCURL_SMTP_REQUEST|PCURL_UPLOAD_REQUEST, NULL, NULL, NULL, 0, 30)) != NULL) {
@@ -449,10 +449,6 @@ static BOOL pcurl_file(const char * url, const char * filename, BOOL upload) {
     else
 	return http_client_download_file(url, filename);
 }
-
-PLEX BOOL smtp_send_blob(const char * url, const char * fromaddr, const char * from,  const char * toaddr, const char * to, const char * subj, const blob_t * template) {
-    return FALSE;
-}
 #endif
 
 static BOOL scp_file(struct uri_t * uri, const char * filename, BOOL download, int bw) {
@@ -578,17 +574,3 @@ PLEX BOOL upload_file(const char * url, const char * filename, int bw) {
     uri_destroy(uri);
     return res;
 }
-
-PLEX BOOL smtp_file(const char * url, const char * fromaddr, const char * from,  const char * toaddr, const char * to, const char * subj, const char * filename, BOOL del) {
-    BOOL	res = FALSE;
-    blob_t	* template = fs_read_to_blob(NULL, filename);
-
-    if (template != NULL) {
-	blob_rewind(template);
-	res = smtp_send_blob(url, fromaddr, from,  toaddr, to, subj, template);
-	blob_free(template);
-    }
-    if (del)
-	unlink(filename);
-    return res;
-}
