@@ -3,10 +3,13 @@
 static BOOL get(HTTP_REQUEST * ctx) {
 
     if (ctx != NULL) {
-	ssize_t	len = blob_printf(ctx->body, "{\"time\":\"%ld\"}", (long)time(NULL));
+	ssize_t	len;
 
-	if (len > 0)
+	blob_rewind(ctx->body);
+	if ((len = blob_printf(ctx->body, "{\"time\":\"%ld\"}", (long)time(NULL))) > 0) {
+	    blob_rewind(ctx->body);
 	    return http_write_body_blob(ctx, __http_built_in_content_types[HTTP_TYPE_APPLICATION_JSON], ctx->body);
+	}
     }
     return FALSE;
 }
