@@ -120,6 +120,8 @@ PLEX void http_free_request_ex(HTTP_REQUEST * ctx, BOOL noclose) {
 	}
 	if (ctx->plugin != NULL)
 	    close_plugin(ctx->plugin);
+	if (ctx->privdata != NULL)
+	    ZFREE(ctx->privdata);
 	if (ctx->query != NULL)
 	    ZFREE(ctx->query);
 	if (ctx->resp_content_type != NULL)
