@@ -275,7 +275,7 @@ static BOOL http_create_client_connection(HTTP_REQUEST * ctx) {
 	return TRUE;
     }
     if ((fd = tcp_connect(ctx->uri->uri_host, ctx->uri->uri_port)) < 0) {
-	log_err("Could not connect to host %s", ctx->uri->uri_host);
+	log_err("Could not connect to host %s:%d", ctx->uri->uri_host, ctx->uri->uri_port);
 	return FALSE;
     }
 
@@ -617,6 +617,12 @@ PLEX WEB_CONTEXT * http_client_request(const char * url, const val_t * hdr, cons
 		ctx->mode |= WEB_APP_DEBUG;
 	    if ((ctx->http->uri = uri_parse(url)) != NULL) {
 		if (_http_check_scheme_ok(ctx, ctx->http->uri->uri_scheme)) {
+		    if (ctx->http->uri->uri_port <= 0) {
+			if (ctx->http->flags & HTTP_SSL_FLAG)
+			    ctx->http->uri->uri_port = 443;
+			else
+			    ctx->http->uri->uri_port = 80;
+		    }
 		    if (options & WEB_CLIENT_OPT_SSL_VERIFY) {
 			ctx->app_ctx.flags |= SSL_APP_CTX_VERIFY_PEER;
 			ctx->app_ctx.cn = ctx->http->uri->uri_host;
