@@ -686,6 +686,7 @@ font-family:arial, helvetica, freesans, sans-serif;font-size:3em;text-decoration
 position:fixed;top:50%;left:50%;transform:translate(-50%, -50%);text-align:center;background:aa6666\n\
 }\n</style>\n\
 <div class=\"centered\">\n%d %s\n</div></body></html>", ctx->retcode, ctx->replymsg, ctx->retcode, ctx->replymsg);
+	    blob_rewind(ctx->body);
 	    http_write_body_blob(ctx, __http_built_in_content_types[HTTP_TYPE_TEXT_HTML], ctx->body);
 	}
     }
@@ -935,10 +936,9 @@ http_read_err:
 
 PLEX BOOL http_write_body_blob(HTTP_REQUEST * ctx, const char * ct, blob_t * blob) {
     BOOL	res = FALSE;
-    size_t	sz = blob_len(blob);
+    size_t	sz = blob_left(blob);
 
-    if ((res = http_start_output(ctx, ct, sz))) {
-	blob_rewind(blob);
+    if ((sz > 0) && (res = http_start_output(ctx, ct, sz))) {
 	res = (BOOL)(pstream_write_blob(ctx->conn, blob) == (ssize_t)sz);
     }
     return res;
@@ -1060,13 +1060,12 @@ PLEX SOCK_EV_ACTIONS web_server_exec(PEER_ADDR * peer) {
     WEB_CONTEXT		* ctx;
     struct http_server	* srv;
 
-    ctx = peer->arg;
-    srv = ctx->localcfg;
-
     if ((peer == NULL) || (peer->arg == NULL) || (peer->stream.fd < 0)) {
 	log_err("Wrong PEER_ADDR data");
 	return SOCK_EV_CANCEL;
     }
+    ctx = peer->arg;
+    srv = ctx->localcfg;
     os_thpool_add_work(srv->thpool, http_server_read_task, (void *)peer, NULL);
 
     return SOCK_EV_DELAY;
