@@ -249,7 +249,7 @@ success:
     }
 }
 
-static const struct passwd *getPWEnt(uid_t uid) {
+static struct passwd *getPWEnt(uid_t uid) {
     struct passwd pwbuf, *pw;
     char *buf;
     struct passwd *passwd;
@@ -631,7 +631,7 @@ static void childProcess(struct Service *service, int width, int height,
 
     // Change working directory
     if (service->useHomeDir) {
-	const struct passwd *pw = getPWEnt(getuid());
+	struct passwd *pw = getPWEnt(getuid());
 
 	if (service->cwd != NULL) {
 	    _exit(1);
@@ -704,16 +704,18 @@ static void launcherDaemon(struct shell_in_a_box_data * data, int fd) {
 	struct msghdr	msg = { 0 };
 	struct cmsghdr	* cmsg;
 
-	if (!sock_watch_single(fd, TRUE, 1000))
+	if (!sock_watch_single(fd, TRUE, 1000)) {
 	    continue;
+	}
 	errno = 0;
 	len = sock_read(fd, &request, sizeof(request), 100);
-	if ((size_t)len != sizeof(request) && errno != EINTR) {
+//	if ((size_t)len != sizeof(request) && errno != EINTR) {
+	if (len < 0) {
 //	    if (len)
 //		log_errno("[server] Failed to read launch request!");
 //	    break;
-log_info("Could not read request from FD %d", fd);
-continue;
+log_errno("Could not read request from FD %d-%ld", fd, len);
+break;
 	}
 
 	// Check whether our read operation got interrupted, because a child
@@ -745,8 +747,8 @@ continue;
 	    break;
 	}
 readURL:
-	if (!sock_watch_single(fd, TRUE, 100))
-	    continue;
+//	if (!sock_watch_single(fd, TRUE, 100))
+//	    continue;
 	len = sock_read(fd, url, request.urlLength + 1, 100);
 	if (len != request.urlLength + 1 && errno != EINTR) {
 	    log_errno("[server] Failed to read URL!");
