@@ -1,7 +1,11 @@
 #include "webapp.h"
 
 static void destroySIABHashEntry(void * arg, const char * key, void * value) {
-    ZFREE((struct shell_in_a_box_data *)value);
+    struct shell_in_a_box_data	* data = value;
+
+    if (data != NULL)
+	os_mutex_lock(&data->mutex);
+    ZFREE(data);
 }
 
 static const char shname[] = "SHELLINABOX";
